# HTML tag

<a id="introduction"></a>

Some text

## CODE block

```python
# comment [asd](asd)
```

### Formula

$ [A+B](A) $

$ [A+B](A) $ text $ [A+B](A) $

#### Grave

Some text
```[A+B](A)```
`[A+B](A)` text `[A+B](A)`

## links ##

[github](https://github.com/AlexanderDokuchaev) https://github.com
[b](./b.md) [d.a](b.md) `[A+B](A)`
<a href="./d/a.md" target="_blank">d.a</a><span href="https://github.com">d.a</span>
[d.a](/tests/test_md_files/d/a.md "tag")

### Header with `quotes` and $math$

#### Badge

[![GitHub Action](https://github.com/AlexanderDokuchaev/md-dead-link-check/actions/workflows/github_action.yml/badge.svg?branch=main "tag")](https://github.com/AlexanderDokuchaev/md-dead-link-check/actions/workflows/github_action.yml "tag")

<!-- markdownlint-disable -->

[top](#)

[top](./b.md#)


- ## badge

 + ## badge

[0](#badge)
[1](#badge-1)
[1](#badge-2)

#### Some [link](b.md) [link2](b.md)

#### Some tag<a id="id"><a id="id2"></a> asd <a id="id3"></a>

[mail](mailto:example@example.example)

<a href="mailto:example@example.example">mail</a>

[ftp](ftp://example.example/example)
https://github.com

<!-- md-dead-link-check: off -->

https://github.com

<!-- md-dead-link-check: on -->

https://github.com, https://github.com/:..
